#
# apache-modperl.spec -- apache mod_perl RPM designed to install along side vanella apache package 
#

%define apachever 1.3.6
%define modperlver 1.21

Summary: The Apache webserver with static mod_perl support.
Name: apache-modperl
Version: %{apachever}_%{modperlver}
Release: 0
Group: System Environment/Daemons

Prereq: apache

# apache sources
Source0: ftp://ftp.apache.org/apache/dist/apache_%{apachever}.tar.gz
Source1: mod_bandwidth.c

# mod_perl sources
Source2: http://www.perl.com/CPAN/by-module/Apache/mod_perl-%{modperlver}.tar.gz

# module sources
Source3: mod_perl-%{modperlver}_modperl-enable
Source4: mod_perl-%{modperlver}_README.RPM

Patch0: apache_1.3.6-redhat.patch
Patch1: apache_1.3.6-apxs.patch
Patch2: apache_1.3.4-srvroot.patch
Patch3: apache_1.3.3-nondbm.patch

Copyright: Freely distributable and usable
BuildRoot: /var/tmp/apache-modperl-root
Prereq: apache


%description
Apache is a powerful, full-featured, efficient and freely-available
Web server. Apache is also the most popular Web server on the
Internet.

The Apache/Perl integration project brings together the full power of
the Perl programming language and the Apache HTTP server. With mod_perl
it is possible to write Apache modules entirely in Perl. In addition,
the persistent interpreter embedded in the server avoids the overhead
of starting an external interpreter and the penalty of Perl start-up time.

This package will install the mod_perl library files on your machine
along with the following two Apache files:

  /usr/lib/apache/mod_include_modperl.so
  /usr/sbin/httpd_modperl

This package does not install a complete apache subtree built with
mod_perl, but rather just the two above files that are different
for mod_perl.  This conceptually thinks of mod_perl as a kind of an
"add on" that we would like to add to the regular apache tree. However,
we are prevented from distributing mod_perl as an actual DSO, because it
is not recommended by the mod_perl developers and various features must
be turned off. So, instead, we distribute a httpd binary with mod_perl
statically linked (httpd_modperl) and the special modified mod_include.so
required for this binary (mod_include_modperl.so).  You can use the exact
same configuration files and other DSO modules, but you just "enable"
the mod_perl "add on" by following the below directions.

To enable mod_perl, do the following:

  (1) Configure /etc/rc.d/init.d/httpd to run httpd_modperl instead of
      httpd by chaning the "daemon" command line.
  (2) Replace mod_include.so with mod_include_modperl.so in the
      module loading section of /etc/httpd/conf/httpd.conf
  (3) Uncomment the "AddModule mod_perl.c" line in /etc/httpd/conf/httpd.conf

Or run the following command: (and the other version to disable mod_perl)

  /usr/sbin/modperl-enable on
  /usr/sbin/modperl-enable off

(This text can also be found in the
/usr/doc/mod_perl-%{version}/README.RPM file.)


%prep
%setup -q -c apache-modperl-%{version} -T -a0 -a2

cd apache_%{apachever}
%patch0 -p1 -b .redhat
%patch1 -p1 -b .apxs
%patch2 -p1 -b .srvroot
%patch3 -p1 -b .nondbm
cd ..

%build
APACHEDIR=apache_%{apachever}
MODPERLDIR=mod_perl-%{modperlver}

cd $MODPERLDIR
perl Makefile.PL \
    APACHE_SRC=../$APACHEDIR/src \
    DO_HTTPD=1 \
    USE_APACI=1 \
    PREP_HTTPD=1 \
    EVERYTHING=1 
make
cd ..

cd $APACHEDIR
OPTIM="$RPM_OPT_FLAGS" \
	./configure --prefix=/usr \
	--with-layout=RedHat \
	--add-module=%{SOURCE1} \
	--enable-module=all \
	--enable-shared=max \
	--disable-rule=WANTHSREGEX \
	--disable-module=auth_dbm \
	--with-perl=/usr/bin/perl \
	--activate-module=src/modules/perl/libperl.a
make
cd ..


%install
rm -rf $RPM_BUILD_ROOT
APACHEDIR=apache_%{apachever}
MODPERLDIR=mod_perl-%{modperlver}

cd $MODPERLDIR

make pure_install PREFIX=$RPM_BUILD_ROOT/usr
mkdir -p $RPM_BUILD_ROOT/home/httpd/htdocs/manual/mod
install -m 644 htdocs/manual/mod/mod_perl.html \
	$RPM_BUILD_ROOT/home/httpd/htdocs/manual/mod

PACKLIST=` echo $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/*/*/auto/mod_perl/.packlist `
mv $PACKLIST $PACKLIST.old
sed -e "s|$RPM_BUILD_ROOT||g" < $PACKLIST.old > $PACKLIST
rm -f $PACKLIST.old

# make the faq
cd faq; make; cd ..
[ -r ../faq ] && rm -Rf ../faq
mkdir ../faq
cp faq/*.html faq/*.txt ../faq

# copy the doco stuff to the top level so %doc can grab it
cp -R README eg ToDo apache-modlist.html ..
PERLDOC_PAGER=cat perldoc INSTALL > ../INSTALL
PERLDOC_PAGER=cat perldoc CREDITS > ../CREDITS
PERLDOC_PAGER=cat perldoc SUPPORT > ../SUPPORT
for F in cgi_to_mod_perl mod_perl_cvs mod_perl_traps \
mod_perl mod_perl_method_handlers mod_perl_tuning ; do
	PERLDOC_PAGER=cat perldoc $F.pod > ../$F
done

cd ..
cd $APACHEDIR

make install root=$RPM_BUILD_ROOT
strip $RPM_BUILD_ROOT/usr/sbin/httpd

# rename the html directory
mv $RPM_BUILD_ROOT/home/httpd/htdocs $RPM_BUILD_ROOT/home/httpd/html

# move special the apache binaries to the new place 
cp $RPM_BUILD_ROOT/usr/lib/apache/mod_include{,_modperl}.so
cp $RPM_BUILD_ROOT/usr/sbin/httpd{,_modperl}

cd ..
cd $MODPERLDIR

# install the header files needed for building libapaci
for F in mod_perl.h mod_perl_version.h mod_perl_xs.h perl_PL.h ; do
	install src/modules/perl/$F $RPM_BUILD_ROOT/usr/include/apache
done

# install the package sources into place
install -m755 %{SOURCE3} $RPM_BUILD_ROOT/usr/sbin/modperl-enable
install -m644 %{SOURCE4} ../README.RPM


%clean
rm -rf $RPM_BUILD_ROOT


%pre
MAGIC_LINE=`httpd -V | grep "Server's Module Magic Number"`
if ! echo $MAGIC_LINE | grep '19990320:0' >/dev/null ; then
	echo ""
	echo "+-------------------------------------------------------+"
	echo "| WARNING -- wrong apache version                       |"
	echo "|                                                       |"
	echo "| The current httpd binary reports with the -V option:  |"
	echo "| $MAGIC_LINE"
	echo "| but we expect a module magic number of '19990320:0'   |"
	echo "|                                                       |"
	echo "| It appears that you have the wrong version of the     |"
	echo "| Apache package to work with this mod_perl package.    |"
	echo "| Things will probably not work, but the install will   |"
	echo "| continue anyway.                                      |"
	echo "+-------------------------------------------------------+"
	echo ""
fi

%post
if [ $1 = 1 ]; then
	echo "mod_perl has been installed, but it is not yet enabled"
	echo "please read" /usr/doc/apache-modperl*/README.RPM
fi

 
%files
%defattr(-,root,root)

# the mod_perl documentation
%doc README faq eg ToDo apache-modlist.html
%doc INSTALL CREDITS SUPPORT
%doc cgi_to_mod_perl mod_perl_cvs mod_perl_traps
%doc mod_perl mod_perl_method_handlers mod_perl_tuning
%doc README.RPM

# the perl library flies
/usr/lib/perl5/man/man3/*
/usr/lib/perl5/site_perl/5.005/*-linux/Apache
/usr/lib/perl5/site_perl/5.005/*-linux/Apache.pm
/usr/lib/perl5/site_perl/5.005/*-linux/Bundle/Apache.pm
/usr/lib/perl5/site_perl/5.005/*-linux/auto/Apache
/usr/lib/perl5/site_perl/5.005/*-linux/auto/mod_perl
/usr/lib/perl5/site_perl/5.005/*-linux/mod_perl*

# mod_perl libarires required for building libapreq
/usr/include/apache/mod_perl.h
/usr/include/apache/mod_perl_version.h
/usr/include/apache/mod_perl_xs.h
/usr/include/apache/perl_PL.h

# the different apache files
/usr/lib/apache/mod_include_modperl.so
/usr/sbin/httpd_modperl

# the package installer file
/usr/sbin/modperl-enable


%changelog
* Thu Oct 14 1999 David Harris <dharris@drh.net>
- upgraded to mod_perl-1.21

* Wed Oct 13 1999 David Harris <dharris@drh.net>
- based on apache-1.3.6-7.src.rpm from Red Hat 6.0
- used apache_modperl-1.3.6-1.19-1.src.rpm by Alex Vorobiev
  <sasha@mathforum.com> as an example.

